@@ -277,7 +277,7 @@ static int test_anr(UV a, UV n, UV r)
  *  compete with the earlier primality proving methods like ECPP and
  *  cyclotomy." - conclusion regarding memory consumption
  */
-int _XS_is_aks_prime(UV n)
+int is_aks_prime(UV n)
 {
   UV r, s, a;
   int verbose;
