@@ -127,6 +127,14 @@ sub twin_prime_count {
   }
   return Math::Prime::Util::PP::twin_prime_count($low,$high);
 }
+sub sum_primes {
+  my($low,$high) = @_;
+  return Math::Prime::Util::PP::sum_primes($low,$high);
+}
+sub print_primes {
+  my($low,$high,$fd) = @_;
+  return Math::Prime::Util::PP::print_primes($low,$high,$fd);
+}
 sub twin_prime_count_approx {
   my($n) = @_;
   _validate_positive_integer($n);
@@ -200,6 +208,12 @@ sub is_perrin_pseudoprime {
   _validate_positive_integer($n);
   return Math::Prime::Util::PP::is_perrin_pseudoprime($n);
 }
+sub is_catalan_pseudoprime {
+  my($n) = @_;
+  return 0 if defined $n && int($n) < 0;
+  _validate_positive_integer($n);
+  return Math::Prime::Util::PP::is_catalan_pseudoprime($n);
+}
 sub is_frobenius_pseudoprime {
   my($n, $P, $Q) = @_;
   return 0 if defined $n && int($n) < 0;
@@ -213,6 +227,12 @@ sub is_frobenius_underwood_pseudoprime {
   _validate_positive_integer($n);
   return Math::Prime::Util::PP::is_frobenius_underwood_pseudoprime($n);
 }
+sub is_frobenius_khashin_pseudoprime {
+  my($n) = @_;
+  return 0 if defined $n && int($n) < 0;
+  _validate_positive_integer($n);
+  return Math::Prime::Util::PP::is_frobenius_khashin_pseudoprime($n);
+}
 sub is_aks_prime {
   my($n) = @_;
   return 0 if defined $n && int($n) < 0;
