@@ -31,6 +31,8 @@ static int do_partial_sieve(UV startp, UV endp) {
  * appropriately filled with this data, then 7, 11, and 13 do not have
  * to be sieved.  It wraps, so multiple memcpy's can be used.  Do be
  * aware that if you start at 0, you'll have to correct the first byte.
+ *
+ * mpu '$g=7*11*13; @b=(0)x$g; for $d (0..$g-1) { $i=0; for $m (1,7,11,13,17,19,23,29) { $n=30*$d+$m; if (gcd($n,$g) != 1) { $b[$d] |= (1<<$i); } $i++; } } for (0..$#b) { printf "0x%02x,",$b[$_]; print "\n" unless ($_+1)%13; } print "\n"'
  */
 #define PRESIEVE_SIZE (7*11*13)
 static const unsigned char presieve13[PRESIEVE_SIZE] =
@@ -335,7 +337,7 @@ int sieve_segment(unsigned char* mem, UV startd, UV endd)
     get_prime_cache(slimit, &sieve);
   }
 
-  START_DO_FOR_EACH_SIEVE_PRIME(sieve, start_base_prime, slimit)
+  START_DO_FOR_EACH_SIEVE_PRIME(sieve, 0, start_base_prime, slimit)
   {
     /* p increments from 17 to at most sqrt(endp).  Note on overflow:
      * 32-bit: limit=     65535, max p =      65521, p*p = ~0-1965854
@@ -399,8 +401,8 @@ int sieve_segment(unsigned char* mem, UV startd, UV endd)
   release_prime_cache(sieve);
 
   if (limit > slimit) { /* We've sieved out most composites, but not all. */
-    START_DO_FOR_EACH_SIEVE_PRIME(mem, 0, endp-startp) {
-      if (!_XS_BPSW(startp + p))    /* If the candidate is not prime, */
+    START_DO_FOR_EACH_SIEVE_PRIME(mem, 0, 0, endp-startp) {
+      if (!BPSW(startp + p))        /* If the candidate is not prime, */
         mem[d_] |= mask_;           /* mark the sieve location.       */
     } END_DO_FOR_EACH_SIEVE_PRIME;
   }
